@@ -1,8 +1,16 @@
+import htmlgenerator as hg
 from django.conf import settings
 
+from . import layout
+
 
 def bread_context(request):
-    ret = {"OVERRIDE_STYLESHEET": getattr(settings, "OVERRIDE_STYLESHEET", None)}
+    ret = {
+        "headerlayout": layout.shell_header.ShellHeader(
+            hg.C("PLATFORMNAME"),
+            "",
+        ),
+    }
     return ret
 
 
