@@ -1,25 +1,27 @@
 import datetime
 import numbers
-import random
 from collections.abc import Iterable
 
+import htmlgenerator as hg
 from ckeditor.fields import RichTextField
 from ckeditor_uploader.fields import RichTextUploadingField
 from dateutil import tz
-from django_countries.fields import CountryField
-from easy_thumbnails.files import get_thumbnailer
-
-import bread.settings as app_settings
 from django.conf import settings
-from django.contrib.contenttypes.fields import GenericForeignKey
 from django.core.exceptions import FieldDoesNotExist
 from django.db import models
+from django.urls import NoReverseMatch
+from django.utils.functional import Promise
 from django.utils.html import format_html, format_html_join, linebreaks, mark_safe
+from django_countries.fields import CountryField
 
+import bread.settings as app_settings
+
+from . import layout
 from .models import AccessConcreteInstanceMixin
+from .utils.urls import reverse_model
 
 
-def render_field(instance, fieldname, adminobject=None):
+def render_field(instance, fieldname):
     if fieldname == "self":
         return as_object_link(instance, str(instance))
 
@@ -27,9 +29,7 @@ def render_field(instance, fieldname, adminobject=None):
         accessor, fieldname = fieldname.split(models.constants.LOOKUP_SEP, 1)
         instance = getattr(instance, accessor, None)
         if isinstance(instance, models.Manager):
-            rendered_fields = [
-                render_field(o, fieldname, adminobject) for o in instance.all()
-            ]
+            rendered_fields = [render_field(o, fieldname) for o in instance.all()]
             return format_html(
                 "<ul>{}</ul>", format_html_join("\n", "<li>{}</li>", rendered_fields)
             )
@@ -38,9 +38,7 @@ def render_field(instance, fieldname, adminobject=None):
         fieldtype = instance._meta.get_field(fieldname)
     except FieldDoesNotExist:
         pass
-    if hasattr(adminobject, fieldname):
-        value = getattr(adminobject, fieldname)(instance)  # noqa
-    elif hasattr(instance, f"get_{fieldname}_display") and not isinstance(
+    if hasattr(instance, f"get_{fieldname}_display") and not isinstance(
         fieldtype, CountryField
     ):
         value = getattr(instance, f"get_{fieldname}_display")()
@@ -51,32 +49,6 @@ def render_field(instance, fieldname, adminobject=None):
     return format_value(value, fieldtype)
 
 
-def render_field_aggregation(queryset, fieldname, adminobject):
-    DEFAULT_AGGREGATORS = {models.DurationField: models.Sum(fieldname)}
-    modelfield = None
-    try:
-        modelfield = queryset.model._meta.get_field(fieldname)
-        if isinstance(modelfield, GenericForeignKey):
-            modelfield = None
-    except FieldDoesNotExist:
-        pass
-    # check if there are aggrations defined on the breadadmin or on the model field
-    aggregation_func = getattr(adminobject, f"{fieldname}_aggregation", None)
-    if aggregation_func is None:
-        aggregation_func = getattr(queryset.model, f"{fieldname}_aggregation", None)
-    # if there is no custom aggregation defined but the field is a database fields, we just count distinct
-    if aggregation_func is None:
-        if type(modelfield) not in DEFAULT_AGGREGATORS:
-            return ""
-        aggregation = DEFAULT_AGGREGATORS[type(modelfield)]
-    else:
-        aggregation = aggregation_func(queryset)
-
-    if isinstance(aggregation, models.Aggregate):
-        return format_value(queryset.aggregate(value=aggregation)["value"], modelfield)
-    return format_value(aggregation, modelfield)
-
-
 def format_value(value, fieldtype=None):
     """Renders a python value in a nice way in HTML. If a field-definition has an attribute "renderer" set, that function will be used to render the value"""
     if hasattr(fieldtype, "renderer"):
@@ -105,10 +77,13 @@ def format_value(value, fieldtype=None):
         return as_image(value)
     if isinstance(value, models.fields.files.FieldFile):
         return as_download(value)
-    if isinstance(value, Iterable) and not isinstance(value, (str, bytes)):
+    if isinstance(value, Iterable) and not isinstance(value, (str, bytes, Promise)):
         return as_list(value)
     if isinstance(value, models.Model):
-        return as_object_link(value)
+        try:
+            return as_object_link(value)
+        except NoReverseMatch:
+            return value
     return value
 
 
@@ -126,29 +101,7 @@ def as_url(value):
 
 
 def as_text(value):
-    char_limit = getattr(
-        settings, "TEXT_FIELD_DISPLAY_LIMIT", app_settings.TEXT_FIELD_DISPLAY_LIMIT
-    )
-    preview = None
-    if len(value) > char_limit:
-        preview = value[:char_limit]
-        if len(preview.splitlines()) > 3:
-            preview = "\n".join(preview.splitlines()[:3])
-        preview = linebreaks(preview, autoescape=True)
-
-    value = linebreaks(value, autoescape=True)
-    if preview:
-        modalid = int(random.random() * 100000000)
-        value = f"""{preview}... <a class="modal-trigger" href="#modal_{modalid}">Show</a>
-<div id="modal_{modalid}" class="modal modal-fixed-footer">
-    <div class="modal-content">
-        <p>{value}</p>
-    </div>
-    <div class="modal-footer">
-        <a href="#!" class="modal-close btn-flat">Close</a>
-    </div>
-</div>"""
-    return mark_safe(value)
+    return mark_safe(linebreaks(value, autoescape=True))
 
 
 def as_time(value):
@@ -172,11 +125,8 @@ def as_countries(value):
     return as_list((c.name for c in value))
 
 
-def as_list(iterable):
-    return format_html(
-        "<ul>{}</ul>",
-        format_html_join("\n", "<li>{}</li>", ((format_value(v),) for v in iterable)),
-    )
+def as_list(iterable, sep=", "):
+    return format_html_join(sep, "{}", ((format_value(v),) for v in iterable))
 
 
 def as_richtext(value):
@@ -188,9 +138,21 @@ def as_download(value):
         return CONSTANTS[None]
     if not value.storage.exists(value.name):
         return mark_safe("<small><emph>File not found</emph></small>")
-    return format_html(
-        '<a class="center" href="{}"><i class="material-icons">open_in_browser</i></a>',
-        value.url,
+    return mark_safe(
+        hg.render(
+            hg.BaseElement(
+                hg.A(
+                    layout.icon.Icon("launch", size=16),
+                    newtab=True,
+                    href=value.url,
+                    style="margin-right: 0.5rem; margin-left: 0.5rem",
+                ),
+                hg.A(
+                    layout.icon.Icon("download", size=16), download=True, href=value.url
+                ),
+            ),
+            {},
+        )
     )
 
 
@@ -199,6 +161,8 @@ def as_image(value):
         return CONSTANTS[None]
     if not value.storage.exists(value.name):
         return mark_safe("<small><emph>Image not found</emph></small>")
+    from easy_thumbnails.files import get_thumbnailer
+
     im = get_thumbnailer(value).get_thumbnail({"size": (100, 100), "quality": 75})
     return format_html(
         '<a class="center" href="{}"><img src={} width="{}" height="{}"/></a>',
@@ -239,24 +203,7 @@ def as_video(value):
     )
 
 
-def object_url(o):
-    from .admin import site
-
-    defaultadmin = site.get_default_admin(o)
-    if defaultadmin is not None:
-        return defaultadmin.reverse("read", o.pk)
-
-
 def as_object_link(obj, label=None):
-    def adminlink(o):
-        url = object_url(o)
-        if url:
-            return format_html(
-                '<a href="{}">{}</a>',
-                url,
-                label or o.__str__(),
-            )
-
     if hasattr(obj, "get_absolute_url"):
         return format_html('<a href="{}">{}</a>', obj.get_absolute_url(), obj)
 
@@ -264,7 +211,11 @@ def as_object_link(obj, label=None):
         isinstance(obj, AccessConcreteInstanceMixin) and obj != obj.concrete
     ):  # prevent endless recursion
         return as_object_link(obj.concrete)
-    return adminlink(obj) or obj.__str__()
+    return format_html(
+        '<a href="{}">{}</a>',
+        reverse_model(obj, "read"),
+        label or obj.__str__(),
+    )
 
 
 MODELFIELD_FORMATING_HELPERS = {
