@@ -1,8 +1,7 @@
+import htmlgenerator as hg
 from django.apps import apps
 from django.utils.text import format_lazy
 
-from .utils import try_call
-
 
 class Group:
     def __init__(
@@ -48,6 +47,10 @@ class Group:
         return any((item.active(request) for item in self.items))
 
 
+def try_call(var, *args, **kwargs):
+    return var(*args, **kwargs) if callable(var) else var
+
+
 class Action:
     """Represents a user-clickable action
     js, label, icon and permissions can be str, lazy string or a callable function.
@@ -76,9 +79,32 @@ class Link(Action):
         )
         self.url = url
 
+    @staticmethod
+    def from_objectaction(object, actionname, label, icon=None, pk_argname="pk"):
+        from .utils.urls import reverse_model
+
+        return Action(
+            hg.F(
+                lambda c, e: format_lazy(
+                    "document.location = '{}'",
+                    reverse_model(
+                        hg.resolve_lazy(object, c, e),
+                        actionname,
+                        kwargs={pk_argname: hg.resolve_lazy(object, c, e).pk},
+                    ),
+                )
+            ),
+            label=label,
+            icon=icon,
+        )
+
 
 class Item:
     def __init__(self, link, group, order=None):
+        if not isinstance(link, Link):
+            raise ValueError(
+                f"argument 'link' must be of type Link but is of type {type(link)}"
+            )
         self.link = link
         self.group = group
         self._order = order
