@@ -1,56 +1,37 @@
-import pkg_resources
-from easy_thumbnails.conf import Settings as thumbnail_settings
-
-__breadapps = []
-for entrypoint in pkg_resources.iter_entry_points(group="breadapp", name="appconfig"):
-    for dependency in entrypoint.load().bread_dependencies:
-        if dependency not in __breadapps:
-            __breadapps.append(dependency)
-
 _third_party_apps = [
-    "crispy_forms",
+    "django_extensions",  # for developer friendliness
+    "guardian",  # per-object permissions
+    "compressor",  # asset handling
+    "simple_history",  # versioning
+    # some additional form fields
     "ckeditor",
     "ckeditor_uploader",
-    "guardian",
+    "djangoql",
+    # for handling global and user preferences
     "dynamic_preferences",
     "dynamic_preferences.users.apps.UserPreferencesConfig",
-    "compressor",
-    "easy_thumbnails",
-    "image_cropping",
+    # very commonly used model fields
+    "django_countries",
     "djmoney",
     "djmoney.contrib.exchange",
+    # task queue system
     "django_celery_results",
     "django_celery_beat",
-    "django_markdown2",
-    "django_filters",
-    "django_extensions",
+    # search index
     "haystack",
-    "whoosh",
     "celery_haystack",
+    "whoosh",
 ]
 _django_apps = [
-    "django.forms",
     "django.contrib.auth",
     "django.contrib.contenttypes",
     "django.contrib.sessions",
     "django.contrib.messages",
     "django.contrib.staticfiles",
-    "django.contrib.humanize",
-    "django.contrib.sites",
 ]
 
-for basedependency in _third_party_apps + _django_apps:
-    if basedependency in __breadapps:
-        __breadapps.remove(basedependency)
-
 # apps which are required for bread to work, order is important
-BREAD_DEPENDENCIES = (
-    ["django.contrib.admin"]
-    + __breadapps
-    + ["bread.apps.BreadConfig"]
-    + _third_party_apps
-    + _django_apps
-)
+BREAD_DEPENDENCIES = ["bread.apps.BreadConfig"] + _third_party_apps + _django_apps
 
 # required to make per-object-permissions work
 AUTHENTICATION_BACKENDS = (
@@ -94,17 +75,22 @@ CKEDITOR_CONFIGS = {
         ],
     },
 }
-# required to compile sass theme
-COMPRESS_PRECOMPILERS = (("text/x-scss", "django_libsass.SassCompiler"),)
 COMPRESS_OFFLINE_CONTEXT = "bread.context_processors.compress_offline_context"
-LIBSASS_OUTPUT_STYLE = "compressed"
+COMPRESS_FILTERS = {
+    "css": [
+        "compressor.filters.css_default.CssAbsoluteFilter",
+        "compressor.filters.cssmin.CSSCompressorFilter",
+    ],
+    "js": ["compressor.filters.jsmin.JSMinFilter"],
+}
 
 # not sure why we need this
 LOGIN_REDIRECT_URL = "/"
 LOGOUT_REDIRECT_URL = "/"
+# named urlpattern to redirect to if login is required
 LOGIN_URL = "login"
 
-# required for compressor (which is the base of the sass compiler)
+# required for compressor
 STATICFILES_FINDERS = [
     "django.contrib.staticfiles.finders.FileSystemFinder",
     "django.contrib.staticfiles.finders.AppDirectoriesFinder",
@@ -123,20 +109,13 @@ MIDDLEWARE = [
     "django.middleware.csrf.CsrfViewMiddleware",
     "django.contrib.auth.middleware.AuthenticationMiddleware",
     "django.contrib.messages.middleware.MessageMiddleware",
-    "django.contrib.sites.middleware.CurrentSiteMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
     "bread.middleware.RequireAuthenticationMiddleware",
+    "simple_history.middleware.HistoryRequestMiddleware",
 ]
-SITE_ID = 1
 
 BREAD_PUBLIC_FILES_PREFIX = "public/"
 
-IMAGE_CROPPING_BACKEND = "image_cropping.backends.easy_thumbs.EasyThumbnailsBackend"
-IMAGE_CROPPING_BACKEND_PARAMS = {}
-THUMBNAIL_PROCESSORS = (
-    "image_cropping.thumbnail_processors.crop_corners",
-) + thumbnail_settings.THUMBNAIL_PROCESSORS
-
 # from default django config
 TEMPLATES = [
     {
@@ -176,16 +155,15 @@ USE_TZ = True
 
 USE_THOUSAND_SEPARATOR = True
 
-CARBON_DESIGN_CONTEXT = {
-    "header": {
-        "name": "PRODUCT_NAME",
-        "company": "COMPANY_NAME",
-        "platform": "PLATFORM_NAME",
-        "actions": [{"title": "ACTION_1", "switcher": None}],
-    },
-}
+DEFAULT_PAGINATION_CHOICES = [
+    25,
+    50,
+    100,
+]  # Defines what the default options for pagination are
 
-DEFAULT_PAGINATION = 1000
-DEFAULT_PAGINATION_CHOICES = [10, 100, 1000]
+HAYSTACK_SIGNAL_PROCESSOR = "haystack.signals.RealtimeSignalProcessor"
 
-HAYSTACK_SIGNAL_PROCESSOR = "celery_haystack.signals.CelerySignalProcessor"
+# This one should only be activated in production or in dev environments with celery ready to run
+# HAYSTACK_SIGNAL_PROCESSOR = "celery_haystack.signals.CelerySignalProcessor"
+
+SIMPLE_HISTORY_FILEFIELD_TO_CHARFIELD = True
