@@ -9,7 +9,10 @@ INSTALLED_APPS = [
     "django.contrib.auth",
     "django.contrib.contenttypes",
     "django.contrib.sites",
+    "guardian",
     "bread",
+    "bread.contrib.reports",
+    "bread.contrib.activities",
 ]
 
 settings.configure(
@@ -20,6 +23,11 @@ settings.configure(
     MIDDLEWARE_CLASSES=(),
     SITE_ID=1,
     INSTALLED_APPS=INSTALLED_APPS,
+    AUTHENTICATION_BACKENDS=(
+        "django.contrib.auth.backends.ModelBackend",
+        "guardian.backends.ObjectPermissionBackend",
+    ),
+    SECRET_KEY="SECRET_KEY_FOR_TESTING",
 )
 
 django.setup()
